@@ -23,31 +23,29 @@
 #include <QDialogButtonBox>
 #include <QFileDialog>
 #include <QFormLayout>
-#include <QLayout>
-#include <QLabel>
-#include <QLineEdit>
-#include <QListWidget>
-#include <QPushButton>
-#include <QTableWidget>
+#include <QFrame>
 #include <QHeaderView>
+#include <QImage>
+#include <QLabel>
+#include <QLayout>
+#include <QLineEdit>
+#include <QLinkedList>
+#include <QListWidget>
+#include <QPixmap>
+#include <QPushButton>
 #include <QSpinBox>
 #include <QTableWidget>
-#include <QImage>
-#include <QPixmap>
-#include <QLinkedList>
-#include <QFrame>
 #include <QTemporaryFile>
 #include <QVBoxLayout>
 
 // KDE Frameworks
-#include <kiconloader.h>
-#include <klocalizedstring.h>
 #include "kimagemapeditor_debug.h"
-#include <khtmlview.h>
-#include <khtml_part.h>
-#include <kstandardguiitem.h>
-#include <KSharedConfig>
 #include <KConfigGroup>
+#include <KHTMLPart>
+#include <KHTMLView>
+#include <KIconLoader>
+#include <KLocalizedString>
+#include <KSharedConfig>
 
 CoordsEdit::CoordsEdit(QWidget *parent, Area* a)
   : QWidget(parent)
@@ -389,7 +387,7 @@ AreaDialog::AreaDialog(KImageMapEditor* parent, Area* a)
   layout->addWidget(tab);
 
   if (a->type() == Area::Default) {
-    // FIXME? Why this useless assignement?
+    // FIXME? Why this useless assignment?
     shape = i18n("Default");
   } else {
     tab->addTab(createCoordsPage(), i18n("Coor&dinates"));
